Most family cases are heard in the Family Court. A limited number of cases are heard in the Family Division of the High Court, for example cases involving international child abduction and cases involving the inherent jurisdiction of the High Court. You can learn more about when the [family court publish judgments in their practice guidance (opens as PDF)](https://www.judiciary.uk/wp-content/uploads/2014/01/transparency-in-the-family-courts-jan-2014-1.pdf){target="\_blank"}.

This court began to regularly transfer judgments to The National Archives in 2022. The oldest judgment from this court included in Find Case Law is from {start_year}.

You can read more about it on the [Family Justice System](https://www.judiciary.uk/courts-and-tribunals/family-law-courts/){target="\_blank"} page on the [HM Courts and Tribunals Service website](https://www.gov.uk/government/organisations/hm-courts-and-tribunals-service/about){target="\_blank"}.
